/***************************************************************************
 *   Copyright (C) 2004 by Work@                                           *
 *   jstubbs@work-at.co.jp                                                 *
 *                                                                         *
 *   This program may be distributed under the terms of the Q Public       *
 *   License as defined by Trolltech AS of Norway and appearing in the     *
 *   file LICENSE.QPL included in the packaging of this file.              *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *
 ***************************************************************************/

#ifndef __CONFIGDIALOG_H__
#define __CONFIGDIALOG_H__

#include <qtabdialog.h>
#include <qlistview.h>
#include <qslider.h>
#include <qfontdatabase.h>
#include <qcombobox.h>

#include "settings.h"
#include "cache.h"

class CheckBoxItem
	: public QCheckListItem
{
	public:
		CheckBoxItem(Settings*, unsigned int, QListView*);
		int compare(QListViewItem*, int, bool) const;
		void promote();
		void demote();
		int index();
		void setIndex(int);
		Site site();
		bool acceptDrop(const QMimeSource* mime) const;
	
	protected:
		void dropped(QDropEvent* e);
	
	private:
		Settings* settings;
		unsigned int _index;
		QListView* view;
};

class SiteListView
	: public QListView
{
	public:
		SiteListView(QWidget* parent = 0, const char* name = 0)
			: QListView(parent, name)
		{}
	
	protected:
		QDragObject* dragObject();
};

class ConfigDialog
	: public QTabDialog
{
	Q_OBJECT
	
	protected slots:
		void updateRssList(SiteList);
		void addRss();
		void removeRss();
		void promoteRss();
		void demoteRss();
		void urlFailed(QString);
		void faceChange(const QString&);
		void sizeChange(int);
		void changeSize(const QString&);
		void fgChange(QColor);
		void changeFg();
		void bgChange(QColor);
		void changeBg();
		void rssEnable(QListViewItem*);
		void setSkin(const QString&);
		void getBrowser();
	
	public:
		ConfigDialog(Settings* settings, Cache* cache, QWidget* parent = 0, const char* name = 0);
	
	protected:
		void resizeEvent(QResizeEvent*);
	
	private:
		Settings* settings;
		Adder* adder;
		QFontDatabase fdb;
		SiteListView* rsslist;
		QSlider* rssreloadslider;
		QPushButton* rssupbutton;
		QPushButton* rssdownbutton;
		QPushButton* rssremovebutton;
		QComboBox* facecombo;
		QComboBox* sizecombo;
		QPushButton* fgbutton;
		QPushButton* bgbutton;
		QComboBox* skincombo;
		QDict<CheckBoxItem> rssitems;
		Site selsite;
};

#endif
